@@ -159,6 +159,21 @@ class qhtml:
 
         subprocess.run(copy_keyword, universal_newlines=True, input=_str)
 
+    def file_read(self,file_name,file_path=''):
+        s = self
+        if file_name:
+            if file_path:
+                dir_path = file_path
+            else:
+                dir_path = os.path.dirname(os.path.realpath(__file__)) + '/'
+            f = open(dir_path + file_name, 'r')
+            read = f.read()
+            f.close()
+
+            return read
+
+        return False
+
     def __get_preview_scripts(self):
         # ** PREVIEW HELPER **
         # -------------------------------------------------------------
@@ -1102,4 +1117,4 @@ class qhtml:
                     print('Pickles Loaded - > ' + str(_templates))
                     return _templates
 
-            return False
+            return False
\ No newline at end of file
